# Tutorials for Lagrangian tracer budget

The following notebooks shows how you can close a tracer budget with Lagrangian particles. They focuses on how this method is implemented in `seaduck`'s `eulerian_budget` and `lagrangian_budget` modules, rather than the rigorous derivation. Interested readers should refer to [our paper "Tracer budgets on Lagrangian Trajectories" published on JAMES](https://agupubs.onlinelibrary.wiley.com/doi/10.1029/2024MS004848).

::::{grid} 1 1 1 2
:class-container: text-center
:gutter: 2

:::{grid-item-card}
:link: budget_tutorial/mean_eul_budg
:link-type: doc
:class-header: bg-light

Preparing the mean salinity budget in ECCO
^^^

```{image} https://github.com/MaceKuailv/seaduck_sciserver_notebook/blob/master/stable_images/eul_bud_thumnail.png?raw=true
:height: 200
```

:::

:::{grid-item-card}
:link: budget_tutorial/particle_bud_tut
:link-type: doc
:class-header: bg-light

Lagrangian budget of mean salinity
^^^

```{image} https://github.com/MaceKuailv/seaduck_sciserver_notebook/blob/master/stable_images/lag_bud_thumnail.png?raw=true
:height: 200
```
